##  Selecting Displayed KPIs
By default, the dashboard shows a set of predefined KPIs. You can select up to 4 KPIs for each use case.
Follow these steps:
  1. In the upper-right corner of the dashboard, click the three-dot icon > Edit Dashboard.
  2. For the use case you need, click Manage KPIs, then adjust the visibility of each KPI using the toggles.
  3. Save your changes.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio31d5969e5f594b11a41456c7d0620588_LowRes.gif)
Selecting Displayed KPIs
